package com.ruoyi.bar.service;

import java.util.HashMap;
import java.util.List;

import com.ruoyi.bar.domain.ActivityJoined;
import com.ruoyi.bar.domain.BarScanCount;
import com.ruoyi.bar.domain.BatchJoined;
import com.ruoyi.bar.domain.WyBeerQrcodeScanLog;
import com.ruoyi.brewery.domain.WyActivity;
import com.ruoyi.system.domain.WyPlatformActivity;
import com.ruoyi.system.domain.vo.WyActivityVO;
import com.ruoyi.system.domain.vo.WyPlatformActivityVO;

/**
 * 酒品二维码扫码记录Service接口
 * 
 * @author kxl
 * @date 2025-01-27
 */
public interface IWyBeerQrcodeScanLogService 
{
    /**
     * 查询酒品二维码扫码记录
     * 
     * @param id 酒品二维码扫码记录主键
     * @return 酒品二维码扫码记录
     */
    public WyBeerQrcodeScanLog selectWyBeerQrcodeScanLogById(Long id);

    /**
     * 查询酒品二维码扫码记录列表
     * 
     * @param wyBeerQrcodeScanLog 酒品二维码扫码记录
     * @return 酒品二维码扫码记录集合
     */
    public List<WyBeerQrcodeScanLog> selectWyBeerQrcodeScanLogList(WyBeerQrcodeScanLog wyBeerQrcodeScanLog);

    /**
     * 新增酒品二维码扫码记录
     * 
     * @param wyBeerQrcodeScanLog 酒品二维码扫码记录
     * @return 结果
     */
    public int insertWyBeerQrcodeScanLog(WyBeerQrcodeScanLog wyBeerQrcodeScanLog);

    List<WyPlatformActivityVO> getPlatformActivityByBeerId(Long beerId, Long barId);

    List<WyActivityVO> getBreweryActivityByBeerId(Long beerId, Long barId);

    HashMap<String, Object> getActivityByBarId(Long barId, Integer status,Long breweryId);

    /**
     * 修改酒品二维码扫码记录
     * 
     * @param wyBeerQrcodeScanLog 酒品二维码扫码记录
     * @return 结果
     */
    public int updateWyBeerQrcodeScanLog(WyBeerQrcodeScanLog wyBeerQrcodeScanLog);

    /**
     * 批量删除酒品二维码扫码记录
     * 
     * @param ids 需要删除的酒品二维码扫码记录主键集合
     * @return 结果
     */
    public int deleteWyBeerQrcodeScanLogByIds(Long[] ids);

    /**
     * 删除酒品二维码扫码记录信息
     * 
     * @param id 酒品二维码扫码记录主键
     * @return 结果
     */
    public int deleteWyBeerQrcodeScanLogById(Long id);

    List<ActivityJoined> selectActivityByBarId(Long barId);

    BatchJoined selectActivityByBatchId(Long batchId);

    int cancelBeerQrcodeScanLogByIds(Long id);

    Integer selectWyBeerQrcodeScanCount(WyBeerQrcodeScanLog wyBeerQrcodeScanLog);

    HashMap<String, Object> selectQrcodeScanCountByDays(Long breweryId, Integer lastDays);

    Integer selectWyBeerQrcodeBarCount(WyBeerQrcodeScanLog wyBeerQrcodeScanLog);

    List<BarScanCount> selectBarScanCount(WyBeerQrcodeScanLog wyBeerQrcodeScanLog);

    Integer scanCountByBarId(Long barId, Integer lastDays);

    Integer scanCountPercentByBarId(Long barId, Integer lastDays);
}
